Run an example for Patient profile integrated in the module manager
Source:R/mock_with_mm.R
mock_with_mm_app.RdLaunches an example app that shows a patient profile module integrated in the module manager surface. Displays data from the safetyData package.